@@ -59,12 +59,11 @@ def fetch_yaml_context(context_location: str, schema_filename: str) -> Dict[str,
             "There is no file with location {}".format(context_location)
         )
 
-    with open(context_location, "r") as file:
-        yaml_resume = yaml.load(file, Loader=yaml.FullLoader)
-
-    msg, validation_flag = validate_resume(yaml_resume, schema_filename)
+    validation_flag, msg = validate_resume(context_location, schema_filename)
     if validation_flag:
         logging.info(msg.format(context_location=context_location))
+        with open(context_location, "r") as file:
+            yaml_resume = yaml.load(file, Loader=yaml.FullLoader)
         return yaml_resume
     else:
         raise ValueError(msg.format(context_location=context_location))
